Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(545)

Unified Diff: net/quic/quic_session.h

Issue 1651153005: changes QUIC negotiation about max open streams which effects server (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@113042237
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_flags.cc ('k') | net/quic/quic_session.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_session.h
diff --git a/net/quic/quic_session.h b/net/quic/quic_session.h
index 02cb62c59cf9f25c7acc34c0d6b5c0fbc422300c..0201d4396cd6cdc767ab8b4a5ef50ae2b41122d3 100644
--- a/net/quic/quic_session.h
+++ b/net/quic/quic_session.h
@@ -203,12 +203,16 @@ class NET_EXPORT_PRIVATE QuicSession : public QuicConnectionVisitorInterface {
// Returns true if any stream is flow controller blocked.
bool IsStreamFlowControlBlocked();
- size_t get_max_open_streams() const { return max_open_streams_; }
+ size_t max_open_incoming_streams() const {
+ return max_open_incoming_streams_;
+ }
- size_t get_max_available_streams() const {
- return max_open_streams_ * kMaxAvailableStreamsMultiplier;
+ size_t max_open_outgoing_streams() const {
+ return max_open_outgoing_streams_;
}
+ size_t MaxAvailableStreams() const;
+
ReliableQuicStream* GetStream(const QuicStreamId stream_id);
// Mark a stream as draining.
@@ -275,7 +279,8 @@ class NET_EXPORT_PRIVATE QuicSession : public QuicConnectionVisitorInterface {
return &closed_streams_;
}
- void set_max_open_streams(size_t max_open_streams);
+ void set_max_open_incoming_streams(size_t max_open_incoming_streams);
+ void set_max_open_outgoing_streams(size_t max_open_outgoing_streams);
void set_largest_peer_created_stream_id(
QuicStreamId largest_peer_created_stream_id) {
@@ -350,8 +355,11 @@ class NET_EXPORT_PRIVATE QuicSession : public QuicConnectionVisitorInterface {
QuicConfig config_;
- // Returns the maximum number of streams this connection can open.
- size_t max_open_streams_;
+ // The maximum number of outgoing streams this connection can open.
+ size_t max_open_outgoing_streams_;
+
+ // The maximum number of incoming streams this connection will allow.
+ size_t max_open_incoming_streams_;
// Static streams, such as crypto and header streams. Owned by child classes
// that create these streams.
« no previous file with comments | « net/quic/quic_flags.cc ('k') | net/quic/quic_session.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698